@@ -229,7 +229,7 @@ static void keypress_battery_graph( ){
 }
 
 static void reset_battery_graph( ){
-	if(original_orientation != O_LANDSCAPE)
+	if(window.supports_rotation && original_orientation != O_LANDSCAPE)
 		rotate_screen(original_orientation, 1);
 }
 
@@ -237,7 +237,7 @@ static void reset_battery_graph( ){
 
 void battery_graph_open_dialog( ){
 	original_orientation = window.orientation;
-	if(window.orientation != O_LANDSCAPE && window.orientation != O_LANDSCAPE_INV)
+	if(window.supports_rotation && window.orientation != O_LANDSCAPE && window.orientation != O_LANDSCAPE_INV)
 		rotate_screen(O_LANDSCAPE, 1);
 	dialog_open(draw_battery_graph, click_battery_graph, keypress_battery_graph, reset_battery_graph, DLG_REDRAW_ON);
 	set_timer(&dialog_refresh_timer, REFRESH_PERIOD);
