@@ -3,6 +3,8 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <time.h>
+#include <esd.h>
 
 #include "window.h"
 #include "main.h"
@@ -10,6 +12,11 @@
 #include "text.h"
 #include "config.h"
 
+////////////////////////////////////////////////////////////////////////// GLOBALS
+
+unsigned screenshot_waiting;
+s_timer screenshot_timer;
+
 //////////////////////////////////////////////////////////////////////////
 
 // this requires the screenshot-tool package to be installed
@@ -21,7 +28,7 @@ void draw_screenshot_button( unsigned force, int x, int y ){
 		// background for all buttons is cleared by draw_window()
 //	} else if(/* condition */){
 //		// button background
-//		x_set_color(bg_color);
+//		x_set_color(secondary_bg_color);
 //		x_fill_rectangle(x, y, 80, 80);
 	} else return;
 
@@ -39,13 +46,13 @@ void draw_screenshot_button( unsigned force, int x, int y ){
 		draw_text(buffer, 16, fg1_color, x+39, y+39, ALIGN_CENTER, ALIGN_MIDDLE, 0);
 
 		// draw delay buttons
-		if(cfg_screenshot_delay > MIN_SCREENSHOT_DELAY) x_set_color(gray_status_color); else x_set_color(innerline_color);
+		if(cfg_screenshot_delay > MIN_SCREENSHOT_DELAY) x_set_color(stepper_color); else x_set_color(line2_color);
 		x_draw_line(x+11,y+59, x+27,y+59); // minus
-		if(cfg_screenshot_delay < MAX_SCREENSHOT_DELAY) x_set_color(gray_status_color); else x_set_color(innerline_color);
+		if(cfg_screenshot_delay < MAX_SCREENSHOT_DELAY) x_set_color(stepper_color); else x_set_color(line2_color);
 		x_draw_line(x+51,y+59, x+67,y+59); // plus horizontal
 		x_draw_line(x+59,y+51, x+59,y+67); // plus vertical
 		// circular button borders
-		x_set_color(innerline_color);
+		x_set_color(line2_color);
 		x_set_style(1, LineOnOffDash); // dotted line
 		x_draw_ellipse(x+ 4, y+44, 29,30); // minus
 		x_draw_ellipse(x+44, y+44, 29,30); // plus
@@ -60,28 +67,42 @@ void draw_screenshot_button( unsigned force, int x, int y ){
 
 //////////////////////////////////////////////////////////////////////////
 
+void take_screenshot( ){
+	// use /usr/bin/screenshot-tool to take shot
+	time_t t = time(NULL);
+	struct tm *tm = localtime(&t);
+	char filename[75], command[200];
+	snprintf(filename, sizeof(filename), "/home/user/MyDocs/.images/screenshot-%d%02d%02d-%02d%02d%02d.png",
+											tm->tm_year + 1900, tm->tm_mon + 1, tm->tm_mday, tm->tm_hour, tm->tm_min, tm->tm_sec);
+	snprintf(command, sizeof(command), "/usr/bin/screenshot-tool -q %s && chown user %s", filename, filename);
+	system(command);
+
+	// use esd to play sound after shot is taken
+	esd_play_file("com.qzx.asui",
+					(file_exists("/usr/share/sounds/camera-capture-image.wav")
+						? "/usr/share/sounds/camera-capture-image.wav"
+						: "/usr/share/sounds/ui-general_warning.wav"),
+					1);
+
+	screenshot_waiting = 0;
+}
+
 void click_screenshot_button( ){
 	if(!screenshot_tool_installed) return;
 
 	if(click.type == CLICK_HOLD){
 
 		// highlight to indicate long press
-		highlight_long_press(widget_x, widget_y, 80,80);
+		highlight_long_press(widget_x, widget_y, 80,80, 1);
 
 	} else if(click.type == CLICK_LONG){
 
-		highlight_selected_area(widget_x, widget_y, 80,80);
+		highlight_selected_area(widget_x, widget_y, 80,80, 1);
 
-		// find a sound file to play when screenshot has been taken
-		const char *soundfile = (file_exists("/usr/share/sounds/camera-capture-image.wav") ? "camera-capture-image.wav" : "ui-general_warning.wav");
+		set_timer(&screenshot_timer, cfg_screenshot_delay);
+		screenshot_waiting = 1;
 
-		time_t t = time(NULL);
-		struct tm *tm = localtime(&t);
-		char command[150];
-		snprintf(command, sizeof(command), "advanced-systemui-screenshot %u %d%02d%02d-%02d%02d%02d %s &", cfg_screenshot_delay-1, tm->tm_year + 1900, tm->tm_mon + 1, tm->tm_mday, tm->tm_hour, tm->tm_min, tm->tm_sec, soundfile);
-		system(command);
-
-		unhighlight_selected_area(widget_x, widget_y, 80,80);
+		unhighlight_selected_area();
 
 	} else if(click.type == CLICK_SHORT && click.y > 39){
 
@@ -104,7 +125,7 @@ void click_screenshot_button( ){
 		}
 
 		// redraw button
-		x_set_color(bg_color);
+		x_set_color(secondary_bg_color);
 		x_fill_rectangle(widget_x, widget_y, 80, 80);
 		draw_screenshot_button(1, widget_x, widget_y);
 		x_flush();
