@@ -16,7 +16,7 @@ void draw_settings_button( unsigned force, int x, int y ){
 		// background for all buttons is cleared by draw_window()
 //	} else if(/* condition */){
 //		// button background
-//		x_set_color(bg_color);
+//		x_set_color(secondary_bg_color);
 //		x_fill_rectangle(x, y, 80, 80);
 	} else return;
 
@@ -32,14 +32,12 @@ void draw_settings_button( unsigned force, int x, int y ){
 void click_settings_button( ){
 	if(click.type != CLICK_SHORT) return;
 
-	highlight_selected_area(widget_x, widget_y, 80,80);
+	highlight_selected_area(widget_x, widget_y, 80,80, 1); // highlight removed when window is redrawn
 	if(file_exists("/root/.asui-settings-test"))
 		system("/root/.asui-settings-test &"); // test
 	else
 		system("/usr/bin/advanced-systemui-settings &"); // release
-	window_unmap();
-
-	// highlight removed when window is redrawn
+	window_unmap(1);
 }
 
 ////////////////////////////////////////////////////////////////////////// BUTTON
