@@ -26,6 +26,7 @@ const char *conf_screen_autolock1 = "/apps/osso/applet/osso-applet-display/lock_
 const char *conf_screen_autolock2 = "/system/osso/dsm/locks/touchscreen_keypad_autolock_enabled";
 const char *conf_screen_stayslit1 = "/apps/osso/applet/osso-applet-display/display_charger";
 const char *conf_screen_stayslit2 = "/system/osso/dsm/display/display_on_with_charger";
+const char *conf_devlock_timeout = "/system/osso/dsm/locks/devicelock_autolock_timeout";
 
 const char *conf_ignore_master_volume = "/apps/asui_state/ignore_master_volume";
 const char *conf_brightness_level = "/apps/asui_state/brightness_level";
@@ -47,10 +48,14 @@ const char *conf_alarm_sound = "/apps/asui_state/alarm_sound";
 const char *conf_alarm_mode = "/apps/asui_state/alarm_mode";
 const char *conf_alarm_timestamp = "/apps/asui_state/alarm_timestamp";
 
+const char *conf_audio_lock_profile = "/apps/asui_state/audio_lock_profile";
+const char *conf_audio_lock_devlock_timeout = "/apps/asui_state/audio_lock_devlock_timeout";
+
 GConfClient *gconf_client;
 
 // statusbar
 unsigned cfg_statusbar_battery_enable, cfg_statusbar_wifi_enable, cfg_statusbar_bluetooth_enable, cfg_statusbar_drain_enable, cfg_statusbar_cpu_enable;
+unsigned cfg_statusbar_wifi_mirror, cfg_statusbar_force_battery_sounds;
 
 // battery
 unsigned cfg_battery_idle_time, cfg_memory_format, cfg_swap_format, cfg_temperature_F, cfg_history_days, cfg_track_usage_events;
@@ -58,7 +63,7 @@ unsigned cfg_battery_idle_time, cfg_memory_format, cfg_swap_format, cfg_temperat
 unsigned cfg_clock_24h, cfg_clock_ampm;
 unsigned cfg_popup_duration, cfg_popup_onmap, cfg_popup_fullscreen, cfg_popup_cooldown, cfg_popup_noasui;
 // brightness
-unsigned cfg_brightness_enhanced, cfg_brightness_allow_zero;
+unsigned cfg_brightness_enhanced, cfg_brightness_allow_zero, cfg_brightness_preset_1, cfg_brightness_preset_2, cfg_brightness_preset_3;
 // WiFi
 unsigned cfg_wifi_disconnect_fix;
 // BRV keys
@@ -70,17 +75,20 @@ unsigned cfg_buttons_dpad_short, cfg_buttons_dpad_long, cfg_buttons_lock1_short,
 unsigned cfg_power_enable_double;
 unsigned cfg_power_action_single, cfg_power_action_double, cfg_power_longpress_shutdown, cfg_power_blanks_when_locked, cfg_power_unlock_key;
 // device lock
-unsigned cfg_secure_button, cfg_secure_action, cfg_secure_power_action_single, cfg_secure_power_action_double;
+unsigned cfg_secure_button, cfg_secure_action, cfg_secure_power_action_single, cfg_secure_power_action_double, cfg_secure_invert_keypad;
 // user interface
 unsigned cfg_tkactive_notifications, cfg_service_size_unit, cfg_short_tap_markers, cfg_start_visible, cfg_threshold_black, cfg_threshold_white;
 char *cfg_theme_file_black = NULL, *cfg_theme_file_white = NULL;
 unsigned cfg_window_slide_unmap, cfg_window_slide_map;
 // alarm
 unsigned cfg_alarm_duration, cfg_alarm_volume_min, cfg_alarm_volume_max, cfg_alarm_volume_step;
+// audio lock
+unsigned cfg_audio_lock_blank_timeout;
 
 // state
 unsigned cfg_theme, cfg_ssh_server, cfg_battery_usage, cfg_screenshot_delay;
 float cfg_power_long_delay, cfg_power_double_delay;
+char *cfg_audio_lock_profile = NULL;
 
 ////////////////////////////////////////////////////////////////////////// WIDGETS
 
@@ -108,6 +116,7 @@ extern s_button button_shutdown;
 extern s_button button_rotate1;
 extern s_button button_rotate2;
 extern s_button button_rotate3;
+extern s_button button_audio_lock;
 extern s_button button_key_repeat;
 extern s_button button_screenshot;
 extern s_button button_screen_stayslit;
@@ -129,6 +138,8 @@ static const char *conf_statusbar_wifi_enable = "/apps/asui/statusbar_wifi_enabl
 static const char *conf_statusbar_bluetooth_enable = "/apps/asui/statusbar_bluetooth_enable";
 static const char *conf_statusbar_drain_enable = "/apps/asui/statusbar_drain_enable";
 static const char *conf_statusbar_cpu_enable = "/apps/asui/statusbar_cpu_enable";
+static const char *conf_statusbar_wifi_mirror = "/apps/asui/statusbar_wifi_mirror";
+static const char *conf_statusbar_force_battery_sounds = "/apps/asui/statusbar_force_battery_sounds";
 
 // battery
 static const char *conf_battery_idle_time = "/apps/asui/battery_idle_time";
@@ -148,6 +159,9 @@ static const char *conf_popup_noasui = "/apps/asui/popup_noasui";
 // brightness
 static const char *conf_brightness_enhanced = "/apps/asui/brightness_enhanced";
 static const char *conf_brightness_allow_zero = "/apps/asui/brightness_allow_zero";
+static const char *conf_brightness_preset_1 = "/apps/asui/brightness_preset_1";
+static const char *conf_brightness_preset_2 = "/apps/asui/brightness_preset_2";
+static const char *conf_brightness_preset_3 = "/apps/asui/brightness_preset_3";
 // WiFi
 static const char *conf_wifi_disconnect_fix = "/apps/asui/wifi_disconnect_fix";
 // BRV keys
@@ -179,6 +193,7 @@ static const char *conf_secure_button = "/apps/asui/secure_button";
 static const char *conf_secure_action = "/apps/asui/secure_action";
 static const char *conf_secure_power_action_single = "/apps/asui/secure_power_action_single";
 static const char *conf_secure_power_action_double = "/apps/asui/secure_power_action_double";
+static const char *conf_secure_invert_keypad = "/apps/asui/secure_invert_keypad";
 // user interface
 static const char *conf_tkactive_notifications = "/apps/asui/tkactive_notifications";
 static const char *conf_service_size_unit = "/apps/asui/service_size_unit";
@@ -195,7 +210,8 @@ static const char *conf_alarm_duration = "/apps/asui/alarm_duration";
 static const char *conf_alarm_volume_min = "/apps/asui/alarm_volume_min";
 static const char *conf_alarm_volume_max = "/apps/asui/alarm_volume_max";
 static const char *conf_alarm_volume_step = "/apps/asui/alarm_volume_step";
-
+// audio lock
+static const char *conf_audio_lock_blank_timeout = "/apps/asui/audio_lock_blank_timeout";
 
 static void make_bool( unsigned *variable, const char *key, unsigned initial_value, unsigned flag ){
 	GError *error = NULL; GConfError code;
@@ -261,6 +277,7 @@ static void make_float( float *variable, const char *key, float initial_value, u
 */
 
 #ifdef ARCH_armel
+static char *empty_string = "";
 static void make_string( char **variable, const char *key, char *initial_value, unsigned flag ){
 	GError *error = NULL; GConfError code;
 	char *value;
@@ -275,15 +292,15 @@ static void make_string( char **variable, const char *key, char *initial_value,
 		if(v){
 			value = malloc(strlen(v)+1);
 			strcpy(value, v);
-		} else value = "";
+		} else value = empty_string;
 	} else {
 		// create the key
 		if(initial_value) value = initial_value;
-		else value = "";
+		else value = empty_string;
 		conf_set_string(key, value);
 	}
-	if(*variable == NULL) *variable = "";
-	if(strcmp(*variable, value)){ if(*variable) free(*variable); *variable = value; hw_changes |= flag; }
+	if(*variable == NULL) *variable = empty_string;
+	if(strcmp(*variable, value)){ if(*variable && *variable != empty_string) free(*variable); *variable = value; hw_changes |= flag; }
 }
 #endif
 
@@ -340,6 +357,7 @@ static void load_buttons( unsigned force_initial ){
 	load_button(&button_edit_widgets,		19, force_initial);
 
 	load_button(&button_sounds,				16, force_initial); // new button: will land in the first empty slot if 16 isn't empty
+	load_button(&button_audio_lock,			 3, force_initial); // new button: will land in the first empty slot if  3 isn't empty
 
 	// find empty cells for homeless buttons
 	while(button_index){
@@ -455,6 +473,8 @@ void config_init( ){
 	gconf_client_unset(gconf_client, conf_statusbar_bluetooth_enable, NULL);
 	gconf_client_unset(gconf_client, conf_statusbar_drain_enable, NULL);
 	gconf_client_unset(gconf_client, conf_statusbar_cpu_enable, NULL);
+	gconf_client_unset(gconf_client, conf_statusbar_wifi_mirror, NULL);
+
 	// battery
 	gconf_client_unset(gconf_client, conf_battery_idle_time, NULL);
 	gconf_client_unset(gconf_client, conf_memory_format, NULL);
@@ -473,6 +493,9 @@ void config_init( ){
 	// brightness
 	gconf_client_unset(gconf_client, conf_brightness_enhanced, NULL);
 	gconf_client_unset(gconf_client, conf_brightness_allow_zero, NULL);
+	gconf_client_unset(gconf_client, conf_brightness_preset_1, NULL);
+	gconf_client_unset(gconf_client, conf_brightness_preset_2, NULL);
+	gconf_client_unset(gconf_client, conf_brightness_preset_3, NULL);
 	// WiFi
 	gconf_client_unset(gconf_client, conf_wifi_disconnect_fix, NULL);
 	// BRV keys
@@ -504,6 +527,7 @@ void config_init( ){
 	gconf_client_unset(gconf_client, conf_secure_action, NULL);
 	gconf_client_unset(gconf_client, conf_secure_power_action_single, NULL);
 	gconf_client_unset(gconf_client, conf_secure_power_action_double, NULL);
+	gconf_client_unset(gconf_client, conf_secure_invert_keypad, NULL);
 	// user interface
 	gconf_client_unset(gconf_client, conf_tkactive_notifications, NULL);
 	gconf_client_unset(gconf_client, conf_service_size_unit, NULL);
@@ -515,11 +539,13 @@ void config_init( ){
 	gconf_client_unset(gconf_client, conf_theme_file_white, NULL);
 	gconf_client_unset(gconf_client, conf_window_slide_unmap, NULL);
 	gconf_client_unset(gconf_client, conf_window_slide_map, NULL);
-
+	// alarm
 	gconf_client_unset(gconf_client, conf_alarm_duration, NULL);
 	gconf_client_unset(gconf_client, conf_alarm_volume_min, NULL);
 	gconf_client_unset(gconf_client, conf_alarm_volume_max, NULL);
 	gconf_client_unset(gconf_client, conf_alarm_volume_step, NULL);
+	// audio lock
+	gconf_client_unset(gconf_client, conf_audio_lock_blank_timeout, NULL);
 
 	gconf_client_unset(gconf_client, "/apps/asui", NULL);
 
@@ -531,6 +557,7 @@ void config_init( ){
 	gconf_client_unset(gconf_client, button_rotate1.conf, NULL);
 	gconf_client_unset(gconf_client, button_rotate2.conf, NULL);
 	gconf_client_unset(gconf_client, button_rotate3.conf, NULL);
+	gconf_client_unset(gconf_client, button_audio_lock.conf, NULL);
 	gconf_client_unset(gconf_client, button_key_repeat.conf, NULL);
 	gconf_client_unset(gconf_client, button_screenshot.conf, NULL);
 	gconf_client_unset(gconf_client, button_screen_stayslit.conf, NULL);
@@ -570,6 +597,8 @@ void config_init( ){
 	gconf_client_unset(gconf_client, conf_alarm_sound, NULL);
 	gconf_client_unset(gconf_client, conf_alarm_mode, NULL);
 	gconf_client_unset(gconf_client, conf_alarm_timestamp, NULL);
+	gconf_client_unset(gconf_client, conf_audio_lock_profile, NULL);
+	gconf_client_unset(gconf_client, conf_audio_lock_devlock_timeout, NULL);
 	gconf_client_unset(gconf_client, "/apps/asui_state", NULL);
 
 	printf("all gconf keys cleared\n");
@@ -649,11 +678,14 @@ static void free_usage_events( ){
 void config_reload( ){
 	#ifdef ARCH_armel
 	// statusbar
-	make_bool(&cfg_statusbar_battery_enable,	conf_statusbar_battery_enable,		1,	0);				// default: 1	enabled
-	make_bool(&cfg_statusbar_wifi_enable,		conf_statusbar_wifi_enable,			1,	0);				// default: 1	enabled
-	make_bool(&cfg_statusbar_bluetooth_enable,	conf_statusbar_bluetooth_enable,	1,	0);				// default: 1	enabled
-	make_bool(&cfg_statusbar_drain_enable,		conf_statusbar_drain_enable,		1,	0);				// default: 1	enabled
-	make_bool(&cfg_statusbar_cpu_enable,		conf_statusbar_cpu_enable,			1,	0);				// default: 1	enabled
+	make_bool(&cfg_statusbar_battery_enable,		conf_statusbar_battery_enable,			1,	0);		// default: 1	enabled
+	make_bool(&cfg_statusbar_wifi_enable,			conf_statusbar_wifi_enable,				1,	0);		// default: 1	enabled
+	make_bool(&cfg_statusbar_bluetooth_enable,		conf_statusbar_bluetooth_enable,		1,	0);		// default: 1	enabled
+	make_bool(&cfg_statusbar_drain_enable,			conf_statusbar_drain_enable,			1,	0);		// default: 1	enabled
+	make_bool(&cfg_statusbar_cpu_enable,			conf_statusbar_cpu_enable,				1,	0);		// default: 1	enabled
+	make_bool(&cfg_statusbar_wifi_mirror,			conf_statusbar_wifi_mirror,				0,	0);		// default: 0	disabled
+	make_bool(&cfg_statusbar_force_battery_sounds,	conf_statusbar_force_battery_sounds,	0,	0);		// default: 0	disabled
+
 	// battery
 	make_bool(&cfg_battery_idle_time,		conf_battery_idle_time,			0,		HW_BATTERY);		// default: 0	don't show idle time
 	make_uint(&cfg_memory_format,			conf_memory_format,				3,		HW_BATTERY);		// default: 3	used/total
@@ -672,6 +704,9 @@ void config_reload( ){
 	// brightness
 	make_bool(&cfg_brightness_enhanced,		conf_brightness_enhanced,		!is_770,HW_BRIGHTNESS);		// default: 1	all 127 brightness levels
 	make_bool(&cfg_brightness_allow_zero,	conf_brightness_allow_zero,		0,		HW_BRIGHTNESS);		// default: 0	don't allow zero brightness
+	make_uint(&cfg_brightness_preset_1,		conf_brightness_preset_1,		12,		HW_BRIGHTNESS);		// default: 12	10%
+	make_uint(&cfg_brightness_preset_2,		conf_brightness_preset_2,		63,		HW_BRIGHTNESS);		// default: 63	50%
+	make_uint(&cfg_brightness_preset_3,		conf_brightness_preset_3,		127,	HW_BRIGHTNESS);		// default: 127	100%
 	// WiFi
 	make_bool(&cfg_wifi_disconnect_fix,		conf_wifi_disconnect_fix,		0,		0);					// default: 0	disabled
 	// BRV keys
@@ -703,6 +738,7 @@ void config_reload( ){
 	make_uint(&cfg_secure_action,			conf_secure_action,				2,		0);					// default: 0	lock&blank
 	make_uint(&cfg_secure_power_action_single,conf_secure_power_action_single,POWER_ACTION_LOCKBLANK, 0);
 	make_uint(&cfg_secure_power_action_double,conf_secure_power_action_double,0,	0);					// default: 0	none
+	make_bool(&cfg_secure_invert_keypad,	conf_secure_invert_keypad,		0,		HW_THEME);			// default: 0	phone style
 	// user interface
 	make_bool(&cfg_tkactive_notifications,	conf_tkactive_notifications,	1,		0);					// default: 1	show screen on unlock notifications
 	make_bool(&cfg_service_size_unit,		conf_service_size_unit,			1,		HW_THEME);			// default: 1	show MB with service sizes
@@ -719,6 +755,8 @@ void config_reload( ){
 	make_uint(&cfg_alarm_volume_min,		conf_alarm_volume_min,			50,		0);					// default:		10-100 / 100
 	make_uint(&cfg_alarm_volume_max,		conf_alarm_volume_max,			100,	0);					// default:		10-100 / 100
 	make_uint(&cfg_alarm_volume_step,		conf_alarm_volume_step,			125,	0);					// default:		0-1000 / 1000
+	// audio lock
+	make_uint(&cfg_audio_lock_blank_timeout,conf_audio_lock_blank_timeout,	2,		0);					// default: 2	2 seconds
 	// state
 	unsigned ignore_master_volume, brightness_level;
 	make_bool(&ignore_master_volume,		conf_ignore_master_volume, 		0,		0);					// default: 0	don't ignore
@@ -728,6 +766,7 @@ void config_reload( ){
 	make_uint(&cfg_ssh_server,				conf_ssh_server,				0,		HW_BRIGHTNESS);		// default: 0	openssh
 	make_bool(&cfg_battery_usage,			conf_battery_usage,				0,		HW_BATTERY);		// default: 0	show active/idle times
 	make_uint(&cfg_screenshot_delay,		conf_screenshot_delay,			5,		HW_THEME);			// default: 5	5 seconds
+	make_string(&cfg_audio_lock_profile,	conf_audio_lock_profile,		"",		HW_THEME);			// default: -	none
 
 	// memory and swap formats can be 0-3
 	if(cfg_memory_format > 3){ cfg_memory_format = 0; conf_set_int(conf_memory_format, 0); }
@@ -814,6 +853,17 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	// only N810 can use zero brightness
 	if(cfg_brightness_allow_zero && !is_810){ cfg_brightness_allow_zero = 0; conf_set_bool(conf_brightness_allow_zero, 0); } // disable
 
+	// reset brightness presets if out of bounds
+	if(cfg_brightness_preset_1 < 1 || cfg_brightness_preset_1 > 127
+	|| cfg_brightness_preset_2 < 1 || cfg_brightness_preset_2 > 127 || cfg_brightness_preset_2 < cfg_brightness_preset_1
+	|| cfg_brightness_preset_3 < 1 || cfg_brightness_preset_3 > 127 || cfg_brightness_preset_3 < cfg_brightness_preset_2
+	){
+		// reset all brightness presets if any are out of bounds
+		cfg_brightness_preset_1 = 12; conf_set_int(conf_brightness_preset_1, cfg_brightness_preset_1);
+		cfg_brightness_preset_2 = 63; conf_set_int(conf_brightness_preset_2, cfg_brightness_preset_2);
+		cfg_brightness_preset_3 = 127; conf_set_int(conf_brightness_preset_3, cfg_brightness_preset_3);
+	}
+
 	// themes
 	//		0 = ALS (n810 only)
 	//		1 = black
@@ -935,6 +985,7 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	cfg_battery_usage = 0; // show active/idle times
 	cfg_screenshot_delay = 5;
 
+	set_string(&cfg_audio_lock_profile, "", 0);
 	#endif
 
 	debug_write("SETTINGS");
@@ -945,7 +996,10 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	debug_write("  cfg_statusbar_bluetooth_enable = %u", cfg_statusbar_bluetooth_enable);
 	debug_write("  cfg_statusbar_drain_enable = %u", cfg_statusbar_drain_enable);
 	debug_write("  cfg_statusbar_cpu_enable = %u", cfg_statusbar_cpu_enable);
+	debug_write("  cfg_statusbar_wifi_mirror = %u", cfg_statusbar_wifi_mirror);
+	debug_write("  cfg_statusbar_force_battery_sounds = %u", cfg_statusbar_force_battery_sounds);
 	#endif
+
 	// battery
 	debug_write("  cfg_battery_idle_time = %u", cfg_battery_idle_time);
 	debug_write("  cfg_memory_format = %u", cfg_memory_format);
@@ -964,6 +1018,9 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	// brightness
 	debug_write("  cfg_brightness_enhanced = %u", cfg_brightness_enhanced);
 	debug_write("  cfg_brightness_allow_zero = %u", cfg_brightness_allow_zero);
+	debug_write("  cfg_brightness_preset_1 = %u", cfg_brightness_preset_1);
+	debug_write("  cfg_brightness_preset_2 = %u", cfg_brightness_preset_2);
+	debug_write("  cfg_brightness_preset_3 = %u", cfg_brightness_preset_3);
 	// WiFi
 	debug_write("  cfg_wifi_disconnect_fix = %u", cfg_wifi_disconnect_fix);
 	// BRV keys
@@ -995,6 +1052,7 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	debug_write("  cfg_secure_action = %u", cfg_secure_action);
 	debug_write("  cfg_secure_power_action_single = %u", cfg_secure_power_action_single);
 	debug_write("  cfg_secure_power_action_double = %u", cfg_secure_power_action_double);
+	debug_write("  cfg_secure_invert_keypad = %u", cfg_secure_invert_keypad);
 	// user interface
 	debug_write("  cfg_tkactive_notifications = %u", cfg_tkactive_notifications);
 	debug_write("  cfg_service_size_unit = %u", cfg_service_size_unit);
@@ -1011,6 +1069,8 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	debug_write("  cfg_alarm_volume_min = %u", cfg_alarm_volume_min);
 	debug_write("  cfg_alarm_volume_max = %u", cfg_alarm_volume_max);
 	debug_write("  cfg_alarm_volume_step = %.3f", cfg_alarm_volume_step);
+	// audio lock
+	debug_write("  cfg_audio_lock_blank_timeout = %u", cfg_audio_lock_blank_timeout);
 
 	debug_write("STATE");
 	// state
@@ -1024,6 +1084,7 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	debug_write("  cfg_screenshot_delay = %u", cfg_screenshot_delay);
 	debug_write("  cfg_power_long_delay = %.3f", cfg_power_long_delay);
 	debug_write("  cfg_power_double_delay = %.3f", cfg_power_double_delay);
+	debug_write("  cfg_audio_lock_profile = \"%s\"", cfg_audio_lock_profile);
 	debug_write("------------------------------");
 }
 
