@@ -27,6 +27,7 @@
  #include "dbus.h"
 #include "dsme.h"
 #include "alarm.h"
+#include "button_audio_lock.h"
 
 ////////////////////////////////////////////////////////////////////////// GLOBALS
 
@@ -76,7 +77,7 @@ static void set_battery_status( e_battery_status status ){
 	else if((!charging && hw_battery.status == BATTERY_CHARGING) || (charging && hw_battery.status != BATTERY_CHARGING)){
 		hw_battery.status = (charging ? BATTERY_CHARGING : BATTERY_AC);
 		dbus_send_charging_status_signal();
-		if(is_value_visible(battery_widget_page)){ hw_changes |= HW_BATTERY; dbus_send_wakeup(_WAKEUP_REFRESH_); }
+		if(is_value_visible(battery_widget_page) || hw_device_locked){ hw_changes |= HW_BATTERY; dbus_send_wakeup(_WAKEUP_REFRESH_); }
 		if(!charging) hw_query_battery(1); // flush
 	}
 
@@ -95,8 +96,12 @@ static void fix_screen_and_keys_and_blank_window( ){
 			// secondary key required to unlock screen, keypad remains unlocked
 			hw_lock_screen();
 			hw_unlock_keys();
+			waiting_for_power_unlock_key = 1;
 			if(!window.is_mapped) window_open_blank(); // open blank to catch keys
 			notify_power_unlock_key();
+		} else if(hw_audio_lock){
+			hw_lock_screen();
+			hw_unlock_keys();
 		} else {
 			window_close_blank(); // signal turned screen on, close the blank window
 			mce_lock_screen(0); // re-lock the screen, this won't send a tklock signal
@@ -136,6 +141,16 @@ static DBusHandlerResult signal_filter( DBusConnection *connection, DBusMessage
 
 		return DBUS_HANDLER_RESULT_HANDLED;
 
+	} else if(dbus_message_is_method_call(message, "com.qzx.asui", "reload_audio_profiles")){
+
+		debug_write("[DBUS] method: reload audio profiles");
+
+		load_audio_profiles();
+		hw_changes |= HW_THEME;
+		dbus_send_wakeup(_WAKEUP_REFRESH_);
+
+		return DBUS_HANDLER_RESULT_HANDLED;
+
 	} else if(dbus_message_is_method_call(message, "com.qzx.asui", "show")){
 
 		debug_write("[DBUS] method: show");
@@ -531,6 +546,11 @@ acting_dead_state = 0;
 					notify_screen_unlocked();
 				}
 
+				if(hw_audio_lock){
+					exit_audio_lock();
+					window_close_blank();
+				}
+
 				// always make sure screen/keypad is unlocked
 				hw_unlock_screen();
 				hw_unlock_keys();
@@ -544,10 +564,13 @@ acting_dead_state = 0;
 				}
 				// always make sure screen/keypad is locked
 				hw_lock_screen();
-				hw_lock_keys();
+				if(hw_audio_lock)
+					hw_unlock_keys();
+				else
+					hw_lock_keys();
 				hw_screen.locked = 1;
 
-				window_close_blank(); // close the blank window, if open
+				if(!hw_audio_lock) window_close_blank(); // close the blank window, if open
 				click.enabled = 1; // don't ignore first tap since screen can't be unlocked by tapping it
 			}
 			dbus_send_wakeup(_WAKEUP_LOCK_BUTTON_);
@@ -723,7 +746,7 @@ acting_dead_state = 0;
 		if(hw_battery.status == BATTERY_DRAINING){
 			hw_battery.status = BATTERY_AC;
 			dbus_send_charging_status_signal();
-			if(is_value_visible(battery_widget_page)){ hw_changes |= HW_BATTERY; dbus_send_wakeup(_WAKEUP_REFRESH_); }
+			if(is_value_visible(battery_widget_page) || hw_device_locked){ hw_changes |= HW_BATTERY; dbus_send_wakeup(_WAKEUP_REFRESH_); }
 
 			hw_new_event("charger", &hw_battery.charger_history_head, &hw_battery.charger_history_tail, 1);
 
@@ -742,7 +765,7 @@ acting_dead_state = 0;
 		if(hw_battery.status != BATTERY_DRAINING){
 			hw_battery.status = BATTERY_DRAINING;
 			dbus_send_charging_status_signal();
-			if(is_value_visible(battery_widget_page)){ hw_changes |= HW_BATTERY; dbus_send_wakeup(_WAKEUP_REFRESH_); }
+			if(is_value_visible(battery_widget_page) || hw_device_locked){ hw_changes |= HW_BATTERY; dbus_send_wakeup(_WAKEUP_REFRESH_); }
 
 			hw_new_event("charger", &hw_battery.charger_history_head, &hw_battery.charger_history_tail, 0);
 
