@@ -80,5 +80,8 @@ void dbus_audio_stop( );
 
 void dbus_send_charging_status_signal( );
 void dbus_send_battery_capacity_signal( );
+void dbus_send_wifi_status_signal( );
+void dbus_send_bluetooth_status_signal( );
+void dbus_send_display_status_signal( );
 
 #define is_value_visible(widget_page) (window.is_mapped && current_dialog_draw == NULL && primary_widgets == widget_page)
