@@ -53,15 +53,36 @@ void draw_themed_image( s_image *image, int x, int y ){
 
 ////////////////////
 
+static unsigned short _get_border_color( unsigned short bg, unsigned short fg ){
+	if(fg > bg) return ((fg-bg)/2+bg)>>8;
+	return ((bg-fg)/2+fg)>>8;
+}
+void get_border_color( XColor *result, XColor *bg, XColor *fg ){
+	unsigned short red = _get_border_color(bg->red, fg->red), green = _get_border_color(bg->green, fg->green), blue = _get_border_color(bg->blue, fg->blue);
+	char value[8];
+	snprintf(value, 8, "#%X%X%X", red, green, blue);
+	XParseColor(window.display, window.colormap, value, result);
+	XAllocColor(window.display, window.colormap, result);
+}
+
 void draw_services_indicator( int status, int x, int y, unsigned height ){
 	if(status == 2){
 		// all services are UP
-		x_set_color(green_color);
+		XColor border;
+		get_border_color(&border, bg_color, green_color);
+		x_set_color((&border));
 		x_fill_ellipse(x-12, y-12, 23,23);
+		x_set_color(green_color);
+		x_fill_ellipse(x-11, y-11, 21,21);
 	} else if(status == 1){
 		// some services are UP
-		x_set_color(yellow_color);
+		XColor border;
+		get_border_color(&border, bg_color, yellow_color);
+		x_set_color((&border));
 		x_fill_ellipse(x-12, y-12, 23,23);
+		x_set_color(yellow_color);
+		x_fill_ellipse(x-11, y-11, 21,21);
+		// start and stop buttons
 		x_set_color(gray_color);
 		x_fill_rectangle(x-53, y-6, 12,12);
 		x_set_color(green_color);
@@ -71,8 +92,12 @@ void draw_services_indicator( int status, int x, int y, unsigned height ){
 		x_draw_line(x, y-(height>>1), x, y+(height>>1));
 	} else {
 		// all services are DOWN
-		x_set_color(gray_color);
+		XColor border;
+		get_border_color(&border, bg_color, gray_color);
+		x_set_color((&border));
 		x_fill_ellipse(x-12, y-12, 23,23);
+		x_set_color(gray_color);
+		x_fill_ellipse(x-11, y-11, 21,21);
 	}
 }
 
