@@ -211,6 +211,23 @@ void dsme_read( ){
 				window_close_popup();
 
 				debug_write("[DSME] screen off");
+
+				waiting_for_power_unlock_key = 0;
+
+				// unlock the keys when the screen blanks after key presses
+				#ifdef ARCH_armel
+				if(hw_audio_lock){
+					unsigned i = 20; // 20 * 50ms = 1 second max delay
+					for(; !get_file_value(keypad_control) && i > 0; i--)
+						usleep(50000); // wait for MCE to lock the keys
+
+// TODO: this should be handled by a timer to prevent main loop from blocking
+//		 then if the screen comes on the timer could be cancelled
+
+					usleep(100000); // wait an additional 100ms
+					hw_unlock_keys();
+				}
+				#endif
 			}
 			if(hw_screen.visible != visible){
 				hw_new_event("screen", &hw_screen.history_head, &hw_screen.history_tail, visible);
@@ -312,6 +329,7 @@ void dsme_set_brightness( unsigned level ){
 
 void dsme_query_devicelock_code( ){
 	#ifdef ARCH_armel
+	debug_write("dsme_query_devicelock_code()");
 	struct {
 		unsigned len;
 		unsigned type;
