@@ -61,7 +61,7 @@ s_hw_sensors hw_sensors;
 
 s_hw_usb hw_usb;
 
-unsigned hw_key_repeat, hw_screen_stays_lit, hw_screen_autolock;
+unsigned hw_audio_lock, hw_key_repeat, hw_screen_stays_lit, hw_screen_autolock;
 
 double last_hw_refresh;
 
@@ -277,10 +277,10 @@ static unsigned sl_ready;
 
 static const char *_mce_devlock_callback_ = "devlock_callback"; // method
 
-static const char *touchscreen_control = "/sys/devices/platform/omap2_mcspi.1/spi1.0/disable_ts";
+const char *touchscreen_control = "/sys/devices/platform/omap2_mcspi.1/spi1.0/disable_ts";
 #define KEYPAD_CONTROL_N800 "/sys/devices/platform/omap2_mcspi.1/spi1.0/disable_kp"
 #define KEYPAD_CONTROL_N810 "/sys/devices/platform/i2c_omap.2/i2c-0/0-0045/disable_kp"
-static const char *keypad_control;
+const char *keypad_control;
 
 static void sl_init( ){
 	if(!hw_screen.visible && !hw_screen.locked && !conf_get_screen_autolock_value()){
@@ -372,6 +372,8 @@ static void mce_init( ){
 	hw_entering_flight_mode = 0;
 	hw_device_locked = 0;
 
+	hw_audio_lock = 0;
+
 	hw_screen.history_head = hw_screen.history_tail = NULL;
 
 	#ifdef ARCH_armel
@@ -745,7 +747,7 @@ static void bme_get_capacity_callback( DBusPendingCall *pending, void *user_data
 			}
 			if(update) bme_update_drain();
 		}
-		if(update && is_value_visible(battery_widget_page)){ hw_changes |= HW_BATTERY; dbus_send_wakeup(_WAKEUP_REFRESH_); }
+		if(update && (is_value_visible(battery_widget_page) || hw_device_locked)){ hw_changes |= HW_BATTERY; dbus_send_wakeup(_WAKEUP_REFRESH_); }
 		hw_initialized &= ~HWIS_BME_CAPACITY;
 	}
 	dbus_message_unref(message);
@@ -1675,6 +1677,7 @@ void hw_refresh_cpu( ){
 }
 
 void hw_refresh( ){
+	debug_write("hw_refresh()");
 	if(!use_minimal_ui){
 		if(brightness_widget_page == primary_widgets)
 			hw_query_brightness_with_delay();
@@ -1698,7 +1701,7 @@ void hw_refresh( ){
 		}
 */
 
-		if(primary_widgets){
+		if(window.supports_rotation && primary_widgets){
 			// an external rotation resulting in a screen resize will produce an X event that is used to recreate window with update_orientation()
 			// however, no event is generated if the screen merely flips orientation so it must be checked and corrected here so the rotation icons can be redrawn
 			if(check_orientation())
@@ -1773,6 +1776,7 @@ void hw_refresh( ){
 	#endif
 
 	last_hw_refresh = current_time;
+	debug_write("hw_refresh() END");
 }
 
 void hw_refresh_popup( ){
