@@ -156,10 +156,12 @@ extern s_hw_gps hw_gps;
 extern s_hw_wifi hw_wifi;
 extern s_hw_sensors hw_sensors;
 extern s_hw_usb hw_usb;
-extern unsigned hw_key_repeat, hw_screen_stays_lit, hw_screen_autolock;
+extern unsigned hw_audio_lock, hw_key_repeat, hw_screen_stays_lit, hw_screen_autolock;
 
 extern double last_hw_refresh;
 
+extern const char *touchscreen_control, *keypad_control;
+
 //////////////////////////////////////////////////////////////////////////
 
 int get_file_value( const char *filename );
