@@ -60,7 +60,7 @@
 
 // open flashlight on fullscreen button
 #include "flashlight.h"
-// draw function for minimal UI and battery refresh timer
+// draw function for minimal UI and battery refresh timer and charge animation timer
 #include "widget_battery.h"
 // draw function for minimal UI
 #include "widget_clock.h"
@@ -108,10 +108,14 @@ unsigned button_autorepeat;
 s_timer motion_timer;
 unsigned (*motion_callback)( );
 
+s_timer charge_animation_timer;
+
+s_timer audio_lock_blank_timer;
+
 unsigned primary_widgets, widget_edit_mode, button_edit_mode;
 s_selected_cell selected_cell;
 unsigned brightness_widget_page, volume_widget_page, battery_widget_page, wifi_widget_page, bluetooth_widget_page, usb_widget_page;
-unsigned flightmode_button_page, keyrepeat_button_page, screenstayslit_button_page, screenautolock_button_page;
+unsigned flightmode_button_page, audiolock_button_page, keyrepeat_button_page, screenstayslit_button_page, screenautolock_button_page;
 		// new *_page variables must be added to window_map() and dialog_reset()
 
 unsigned power_unlock_keys[] = {0, KEYCODE_FULLSCREEN, KEYCODE_HOME, KEYCODE_ESCAPE, KEYCODE_DPAD_CENTER, KEYCODE_MENU};
@@ -119,6 +123,7 @@ char *power_unlock_messages[] = {"",
 	"Press FULLSCREEN key to unlock", "Press HOME key to unlock", "Press ESCAPE key to unlock",
 	"Press DPAD CENTER key to unlock", "Press MENU key to unlock"
 };
+unsigned waiting_for_power_unlock_key = 0;
 
 char *charging_boot_message = "press and hold power button to startup";
 
@@ -520,6 +525,9 @@ void test_write( const char *format, ... ){
 		fprintf(test_file, "[%.6f]  %s\n", current_time-test_start_time, buffer);
 		fflush(test_file);
 	}
+	#ifdef DEBUG_TO_STDOUT
+	printf("[%.6f]  %s\n", current_time-test_start_time, buffer);
+	#endif
 }
 #endif
 
@@ -623,6 +631,8 @@ static void draw_editmode_buttons( unsigned landscape ){
 void draw_window( unsigned force ){
 	if(!window.is_mapped) return;
 
+	debug_write("draw_window(%s)", force ? "force" : "");
+
 	if(hw_changes & HW_THEME) force = 1; // color theme changed
 
 	if(current_dialog_draw){
@@ -847,6 +857,7 @@ x_reset_style();
 	hw_changes = svc_changes = 0;
 
 	x_flush();
+	debug_write("draw_window()");
 }
 
 ////////////////////////////////////////////////////////////////////////// CLICKS
@@ -957,7 +968,7 @@ static void highlight_button_bar( ){
 	// this usleep also fixes a problem where X wouldn't update the window contents for long periods of time
 }
 
-#define WINDOW_SLIDE_DELTA 15
+#define WINDOW_SLIDE_DELTA 10
 
 static void screen_event( ){
 	if(current_dialog_draw){
@@ -971,7 +982,7 @@ static void screen_event( ){
 			// LANDSCAPE
 			if(click.start_y < 80){
 				// buttons
-				if(click.type == CLICK_DRAG && click.start_y + click.offset_y < 80 && (click.offset_x >= 200 || click.offset_x <= -200)){
+				if(click.type == CLICK_DRAG && window.y + click.start_y + click.offset_y < 80 && (click.offset_x >= 200 || click.offset_x <= -200)){
 					if(window.y) window_slide(0,0);
 
 					// change page with a horizontal swipe along button bar (25% length)
@@ -983,13 +994,18 @@ static void screen_event( ){
 					// throttle taps when switching pages
 					throttle_taps(&ui_throttle);
 					finalize_tap(ui_throttle);
-				} else if(click.offset_x >= -100 && click.offset_x <= 100 && click.start_y + click.offset_y > 80){
-					if(click.type == CLICK_DRAG && click.start_y + click.offset_y > 90){
-						// hide the window with a vertical swipe from button bar to widgets (10 pixels into widgets, +-100 pixel horizontal deviation)
-						window_unmap(1);
+				} else if(click.offset_x >= -100 && click.offset_x <= 100 && window.y + click.start_y + click.offset_y > 80){
+					if(click.type == CLICK_DRAG){
+						if(window.y > 30){
+							// hide the window with a vertical swipe from button bar to widgets (10 pixels into widgets, +-100 pixel horizontal deviation)
+							window_unmap(1);
+						} else {
+							// snap window back
+							window_slide(0,0);
+						}
 					} else if(click.type == CLICK_MOTION){
 						// slide the window down as finger moves
-						int y = (click.start_y + click.offset_y) - 80;
+						int y = (window.y + click.start_y + click.offset_y) - 80;
 						if(y > window.y+WINDOW_SLIDE_DELTA || y < window.y-WINDOW_SLIDE_DELTA)
 							window_slide(0, y);
 					}
@@ -1034,7 +1050,7 @@ static void screen_event( ){
 			// PORTRAIT
 			if(click.start_x >= 400){
 				// buttons
-				if(click.type == CLICK_DRAG && click.start_x + click.offset_x >= 400 && (click.offset_y >= 200 || click.offset_y <= -200)){
+				if(click.type == CLICK_DRAG && window.x + click.start_x + click.offset_x >= 400 && (click.offset_y >= 200 || click.offset_y <= -200)){
 					if(window.x) window_slide(0,0);
 
 					// change page with a vertical swipe along button bar (25% length)
@@ -1046,13 +1062,18 @@ static void screen_event( ){
 					// throttle taps when switching pages
 					throttle_taps(&ui_throttle);
 					finalize_tap(ui_throttle);
-				} else if(click.offset_y >= -100 && click.offset_y <= 100 && click.start_x + click.offset_x < 400){
-					if(click.type == CLICK_DRAG && click.start_x + click.offset_x < 390){
-						// hide the window with a horizontal swipe from button bar to widgets (10 pixels into widgets, +-100 pixel vertical deviation)
-						window_unmap(1);
+				} else if(click.offset_y >= -100 && click.offset_y <= 100 && window.x + click.start_x + click.offset_x < 400){
+					if(click.type == CLICK_DRAG){
+						if(window.x < -30){
+							// hide the window with a horizontal swipe from button bar to widgets (10 pixels into widgets, +-100 pixel vertical deviation)
+							window_unmap(1);
+						} else {
+							// snap window back
+							window_slide(0,0);
+						}
 					} else if(click.type == CLICK_MOTION){
 						// slide the window left as finger moves
-						int x = (click.start_x + click.offset_x) - 400;
+						int x = (window.x + click.start_x + click.offset_x) - 400;
 						if(x < window.x-WINDOW_SLIDE_DELTA || x > window.x+WINDOW_SLIDE_DELTA)
 							window_slide(x,0);
 					}
@@ -1566,6 +1587,13 @@ if(runlevel == 2){
 	debug_write("INIT: resume alarm?");
 	alarm_resume(0); // resume an alarm if ASUI was killed
 
+	// restore devlock timeout if ASUI crashed or restarted while audio lock was active
+	int audio_lock_devlock_timeout = conf_get_int(conf_audio_lock_devlock_timeout);
+	if(audio_lock_devlock_timeout > 0){
+		conf_set_int(conf_devlock_timeout, audio_lock_devlock_timeout);
+		conf_set_int(conf_audio_lock_devlock_timeout, 0);
+	}
+
 	////////////////////
 
 	debug_write("INIT: X11");
@@ -1580,6 +1608,8 @@ if(runlevel == 2){
 	set_timer(&key_timer, BUTTON_CHECK_PERIOD);																keypress.key_down = 0; /* global */
 	set_timer(&brightness_timer, BRIGHTNESS_CHECK_PERIOD);
 	/* global motion_timer, don't need to clear it */			motion_callback = NULL; /* global */		unsigned has_motion = 0;
+	set_timer(&charge_animation_timer, 1.0);
+	set_timer(&audio_lock_blank_timer, 0.0);
 
 	screenshot_waiting = 0;
 
@@ -1655,6 +1685,8 @@ if(runlevel == 2){
 				// this event will turn on the screen, if off
 				dsme_display_state_waiting = 0; // reset blanking pause check
 
+				if(window.tk_events_disabled) break;
+
 				if(!click.enabled && hw_screen.visible && !use_minimal_ui)
 					if(current_time - hw_screen.visible_time > 0.5)
 						click.enabled = 1; // screen has been on for more than 500ms, allow this tap
@@ -1682,6 +1714,8 @@ if(runlevel == 2){
 			case MotionNotify: // 6
 				// e.xmotion.x, e.xmotion.y
 
+				if(window.tk_events_disabled) break;
+
 				if(click.enabled && !click.popup_window){
 					if(click.motion_x != e.xmotion.x || click.motion_y != e.xmotion.y){
 						click.type = CLICK_MOTION;
@@ -1703,6 +1737,8 @@ if(runlevel == 2){
 			case ButtonRelease: // 5
 				// e.xbutton.x, e.xbutton.y
 
+				if(window.tk_events_disabled) break;
+
 				if(click.popup_window){
 
 					window_close_popup();
@@ -1746,6 +1782,8 @@ if(runlevel == 2){
 				// this event will turn on the screen, if off
 				dsme_display_state_waiting = 0; // reset blanking pause check
 
+				if(window.tk_events_disabled) break;
+
 				if(!click.enabled && hw_screen.visible && !use_minimal_ui)
 					if(current_time - hw_screen.visible_time > 0.5)
 						click.enabled = 1; // screen has been on for more than 500ms, allow this key
@@ -1770,6 +1808,8 @@ if(runlevel == 2){
 			case KeyRelease: // 3
 				// e.xkey.keycode
 
+				if(window.tk_events_disabled) break;
+
 				debug_write("KeyRelease[main]: %d", e.xkey.keycode);
 
 				if(cfg_power_unlock_key && hw_screen.locked){
@@ -2222,6 +2262,28 @@ if(runlevel == 2){
 						next_timer_duration = motion_timer.remaining;
 			}
 
+			// CHARGE ANIMATION
+			if(hw_battery.status == BATTERY_CHARGING && (
+				(hw_device_locked && current_dialog_draw == draw_secure_keypad)
+				||
+				(!hw_device_locked && current_dialog_draw == NULL && battery_widget_page == primary_widgets)
+			)){
+				if(is_timer_ready(&charge_animation_timer))
+					animate_battery_widget(1);
+
+				if(next_timer_duration <= 0.0 || charge_animation_timer.remaining < next_timer_duration)
+					next_timer_duration = charge_animation_timer.remaining;
+			}
+
+			// AUDIO LOCK
+			if(audio_lock_blank_timer.duration){
+				if(is_timer_ready(&audio_lock_blank_timer)){
+					mce_blank_screen();
+					audio_lock_blank_timer.duration = 0.0;
+				} else if(next_timer_duration <= 0.0 || audio_lock_blank_timer.remaining < next_timer_duration)
+					next_timer_duration = audio_lock_blank_timer.remaining;
+			}
+
 		}
 
 		if(dsme_display_state_waiting){
@@ -2261,6 +2323,9 @@ if(runlevel == 2){
 		if(hw_changes && (current_dialog_draw == NULL || hw_changes & (HW_THEME|HW_CPU|HW_BATTERY|HW_TEMPERATURE)))
 			draw_window(0);
 
+		// failsafe in case MCE doesn't unlock device -- re-enable key and screen events
+		if(window.tk_events_disabled && current_time >= window.tk_events_disabled + 5.0) window_enable_all_events();
+
 	}
 
 	////////////////////
@@ -2269,6 +2334,6 @@ exit:
 
 	debug_write("exit: cleaning up");
 	test_write("exit: cleaning up");
-	clean_up(2);
+	clean_up();
 	return EXIT_SUCCESS;
 }
