@@ -413,6 +413,7 @@ void svc_refresh( ){
 		if(svc_bluetooth_status != tmp_status || svc_bluetooth_size != sc_bluetooth_size) svc_changes |= SVC_BLUETOOTH;
 		svc_bluetooth_status = tmp_status;
 		svc_bluetooth_size = sc_bluetooth_size;
+		debug_write("  bluetooth status = %u", svc_bluetooth_status);
 	}
 
 	// GPS
@@ -432,6 +433,7 @@ void svc_refresh( ){
 		if(svc_gps_status != tmp_status || svc_gps_size != sc_gps_size) svc_changes |= SVC_GPS;
 		svc_gps_status = tmp_status;
 		svc_gps_size = sc_gps_size;
+		debug_write("  gps status = %u", svc_gps_status);
 	}
 
 	// WIFI
@@ -449,6 +451,7 @@ void svc_refresh( ){
 		if(svc_wifi_status != tmp_status || svc_wifi_size != sc_wifi_size) svc_changes |= SVC_WIFI;
 		svc_wifi_status = tmp_status;
 		svc_wifi_size = sc_wifi_size;
+		debug_write("  wifi status = %u", svc_wifi_status);
 	}
 
 	// AUDIO
@@ -466,6 +469,7 @@ void svc_refresh( ){
 		if(svc_audio_status != tmp_status || svc_audio_size != sc_audio_size) svc_changes |= SVC_AUDIO;
 		svc_audio_status = tmp_status;
 		svc_audio_size = sc_audio_size;
+		debug_write("  audio status = %u", svc_audio_status);
 	}
 
 	// DESKTOP
@@ -474,6 +478,7 @@ void svc_refresh( ){
 		if(svc_desktop_status != tmp_status || svc_desktop_size != sc_desktop_size) svc_changes |= SVC_DESKTOP;
 		svc_desktop_status = tmp_status;
 		svc_desktop_size = sc_desktop_size;
+		debug_write("  desktop status = %u", svc_desktop_status);
 	}
 
 	// SSH
@@ -500,6 +505,7 @@ void svc_refresh( ){
 			svc_ssh_size = sc_dropbear_size;
 		}
 	}
+	debug_write("  ssh status = %u", svc_ssh_status);
 
 	// VPN
 	if(svc_vpn_installed){
@@ -508,6 +514,7 @@ void svc_refresh( ){
 		svc_vpn_status = tmp_status;
 		svc_vpn_size = sc_vpn_size;
 	}
+	debug_write("  vpn status = %u", svc_vpn_status);
 
 	last_svc_refresh = current_time;
 }
