@@ -28,6 +28,7 @@
 #include "device_lock.h"
 #include "ui.h"
 #include "alarm.h"
+#include "audio_lock.h"
 #include "services.h"
 #include "mce.h"
 
@@ -37,15 +38,24 @@ unsigned is_770, is_800, is_810;
 
 //////////////////////////////////////////////////////////////////////////
 
+static unsigned reload_timer = 0;
 static DBusConnection *system_bus;
 static DBusError dbus_error;
 
-void asui_reload_settings( ){
+static gboolean asui_reload_settings_timer( gpointer data ){
 	DBusMessage *message = dbus_message_new_method_call("com.qzx.asui", "/com/qzx/asui", "com.qzx.asui", "reload_config");
 	dbus_message_set_no_reply(message, TRUE);
 	if(dbus_connection_send(system_bus, message, NULL) != FALSE)
 		dbus_connection_flush(system_bus);
 	dbus_message_unref(message);
+
+	// destroy timer
+	reload_timer = 0;
+	return FALSE;
+}
+void asui_reload_settings( ){
+	if(reload_timer) g_source_remove(reload_timer);
+	reload_timer = g_timeout_add(1000, asui_reload_settings_timer, NULL);
 }
 
 unsigned file_exists( const char *file ){
@@ -63,6 +73,8 @@ const char *conf_statusbar_wifi_enable = "/apps/asui/statusbar_wifi_enable";
 const char *conf_statusbar_bluetooth_enable = "/apps/asui/statusbar_bluetooth_enable";
 const char *conf_statusbar_drain_enable = "/apps/asui/statusbar_drain_enable";
 const char *conf_statusbar_cpu_enable = "/apps/asui/statusbar_cpu_enable";
+const char *conf_statusbar_wifi_mirror = "/apps/asui/statusbar_wifi_mirror";
+const char *conf_statusbar_force_battery_sounds = "/apps/asui/statusbar_force_battery_sounds";
 
 // battery
 const char *conf_battery_idle_time = "/apps/asui/battery_idle_time";
@@ -82,6 +94,9 @@ const char *conf_popup_noasui = "/apps/asui/popup_noasui";
 // brightness
 const char *conf_brightness_enhanced = "/apps/asui/brightness_enhanced";
 const char *conf_brightness_allow_zero = "/apps/asui/brightness_allow_zero";
+const char *conf_brightness_preset_1 = "/apps/asui/brightness_preset_1";
+const char *conf_brightness_preset_2 = "/apps/asui/brightness_preset_2";
+const char *conf_brightness_preset_3 = "/apps/asui/brightness_preset_3";
 // WiFi
 const char *conf_wifi_disconnect_fix = "/apps/asui/wifi_disconnect_fix";
 // RBV keys
@@ -113,6 +128,7 @@ const char *conf_secure_button = "/apps/asui/secure_button";
 const char *conf_secure_action = "/apps/asui/secure_action";
 const char *conf_secure_power_action_single = "/apps/asui/secure_power_action_single";
 const char *conf_secure_power_action_double = "/apps/asui/secure_power_action_double";
+const char *conf_secure_invert_keypad = "/apps/asui/secure_invert_keypad";
 // user interface
 const char *conf_tkactive_notifications = "/apps/asui/tkactive_notifications";
 const char *conf_service_size_unit = "/apps/asui/service_size_unit";
@@ -129,6 +145,8 @@ const char *conf_alarm_duration = "/apps/asui/alarm_duration";
 const char *conf_alarm_volume_min = "/apps/asui/alarm_volume_min";
 const char *conf_alarm_volume_max = "/apps/asui/alarm_volume_max";
 const char *conf_alarm_volume_step = "/apps/asui/alarm_volume_step";
+// audio lock
+const char *conf_audio_lock_blank_timeout = "/apps/asui/audio_lock_blank_timeout";
 
 //////////////////////////////////////////////////////////////////////////
 
@@ -459,6 +477,7 @@ int main( int argc, char *argv[] ){
 		new_main_button(main_content_box, "Device Lock", device_lock_click_callback);
 		new_main_button(main_content_box, "User Interface", ui_click_callback);
 		new_main_button(main_content_box, "Alarm", alarm_click_callback);
+		new_main_button(main_content_box, "Audio Lock", audio_lock_click_callback);
 	new_main_separator();
 		new_main_button(main_content_box, "Services", services_click_callback);
 		new_main_button(main_content_box, "MCE", mce_click_callback);
