@@ -30,6 +30,8 @@ extern const char *conf_statusbar_wifi_enable;
 extern const char *conf_statusbar_bluetooth_enable;
 extern const char *conf_statusbar_drain_enable;
 extern const char *conf_statusbar_cpu_enable;
+extern const char *conf_statusbar_wifi_mirror;
+extern const char *conf_statusbar_force_battery_sounds;
 
 // battery
 extern const char *conf_battery_idle_time;
@@ -49,6 +51,9 @@ extern const char *conf_popup_noasui;
 // brightness
 extern const char *conf_brightness_enhanced;
 extern const char *conf_brightness_allow_zero;
+extern const char *conf_brightness_preset_1;
+extern const char *conf_brightness_preset_2;
+extern const char *conf_brightness_preset_3;
 // WiFi
 extern const char *conf_wifi_disconnect_fix;
 // RBV keys
@@ -80,6 +85,7 @@ extern const char *conf_secure_button;
 extern const char *conf_secure_action;
 extern const char *conf_secure_power_action_single;
 extern const char *conf_secure_power_action_double;
+extern const char *conf_secure_invert_keypad;
 // user interface
 extern const char *conf_tkactive_notifications;
 extern const char *conf_service_size_unit;
@@ -96,6 +102,8 @@ extern const char *conf_alarm_duration;
 extern const char *conf_alarm_volume_min;
 extern const char *conf_alarm_volume_max;
 extern const char *conf_alarm_volume_step;
+// audio lock
+extern const char *conf_audio_lock_blank_timeout;
 
 extern GtkWidget *section_content_box;
 void new_scrolling_vbox( GtkWidget *parent, GtkWidget **container, GtkWidget **content );
