@@ -97,14 +97,22 @@ static s_service *services, *services_tail;
 
 static unsigned asui_running, systemui_running;
 static GtkWidget *startstop_asui_button, *restart_asui_button, *startstop_systemui_button, *restart_systemui_button;
+static unsigned in_set_startstop_button;
+
+static void set_startstop_button( GtkWidget *button, unsigned running ){
+	in_set_startstop_button = 1;
+	gtk_button_set_label(GTK_BUTTON(button), (running ? "Stop" : "Start"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), (running ? TRUE : FALSE));
+	in_set_startstop_button = 0;
+}
 
 static void update_running_buttons( ){
 	// enable restart button if service is running
 	gtk_widget_set_sensitive(restart_asui_button, asui_running);
 	gtk_widget_set_sensitive(restart_systemui_button, systemui_running);
 	// set label on start/stop buttons
-	gtk_button_set_label(GTK_BUTTON(startstop_asui_button), (asui_running ? "Stop" : "Start"));
-	gtk_button_set_label(GTK_BUTTON(startstop_systemui_button), (systemui_running ? "Stop" : "Start"));
+	set_startstop_button(startstop_asui_button, asui_running);
+	set_startstop_button(startstop_systemui_button, systemui_running);
 	// disable the other service start/stop button
 	gtk_widget_set_sensitive(startstop_asui_button, !systemui_running);
 	gtk_widget_set_sensitive(startstop_systemui_button, !asui_running);
@@ -113,7 +121,7 @@ static void update_running_buttons( ){
 static void update_startstop_buttons( s_service *service ){
 	// start and stop buttons
 	if(service->proc_name && service->allow_startstop)
-		gtk_button_set_label(GTK_BUTTON(service->widget_start), (service->running == IS_STARTED ? "Stop" : "Start"));
+		set_startstop_button(service->widget_start, service->running == IS_STARTED);
 	else if(service->allow_startstop){
 		// do nothing
 	} else if(service->running != IS_UNKNOWN)
@@ -183,6 +191,8 @@ static void update_service_states( ){
 }
 
 static void click_startstop_asui_button_callback( GtkWidget *widget, gpointer data ){
+	if(in_set_startstop_button) return;
+
 	if(asui_running)
 		system("/etc/init.d/advanced-systemui stop");
 	else
@@ -196,6 +206,8 @@ static void click_restart_asui_button_callback( GtkWidget *widget, gpointer data
 }
 
 static void click_startstop_systemui_button_callback( GtkWidget *widget, gpointer data ){
+	if(in_set_startstop_button) return;
+
 	if(systemui_running)
 		system("/etc/init.d/osso-systemui stop");
 	else
@@ -416,6 +428,8 @@ static GtkWidget *new_boot_checkbox( GtkWidget *parent, s_service *service ){
 }
 
 static void click_startstop_service_callback( GtkWidget *widget, gpointer data ){
+	if(in_set_startstop_button) return;
+
 	s_service *service = (s_service *)data;
 	char buffer[200];
 	snprintf(buffer, sizeof(buffer), "/etc/init.d/%s %s", service->init_name, (service->running == IS_STARTED ? "stop" : "start"));
@@ -545,8 +559,8 @@ service->allow_boot = 0;
 	label = gtk_label_new(ASUI_NAME);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 20);
 	gtk_widget_show(label);
-	startstop_asui_button = new_button(hbox, "", click_startstop_asui_button_callback, NULL);
-	restart_asui_button = new_button(hbox, "Restart", click_restart_asui_button_callback, NULL);
+	startstop_asui_button = new_toggle_button(hbox, "", click_startstop_asui_button_callback, NULL, 0, FALSE, FALSE);
+	restart_asui_button = new_toggle_button(hbox, "Restart", click_restart_asui_button_callback, NULL, 0, FALSE, FALSE);
 
 	hbox = gtk_hbox_new(FALSE, 10);
 	gtk_box_pack_start(GTK_BOX(section_content_box), hbox, FALSE, FALSE, 10);
@@ -554,8 +568,9 @@ service->allow_boot = 0;
 	label = gtk_label_new(SYSTEMUI_NAME);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 20);
 	gtk_widget_show(label);
-	startstop_systemui_button = new_button(hbox, "", click_startstop_systemui_button_callback, NULL);
-	restart_systemui_button = new_button(hbox, "Restart", click_restart_systemui_button_callback, NULL);
+	startstop_systemui_button = new_toggle_button(hbox, "", click_startstop_systemui_button_callback, NULL, 0, FALSE, FALSE);
+	restart_systemui_button = new_toggle_button(hbox, "Restart", click_restart_systemui_button_callback, NULL, 0, FALSE, FALSE);
+	in_set_startstop_button = 0;
 
 	update_running_buttons();
 
@@ -579,8 +594,8 @@ service->allow_boot = 0;
 	hbox = gtk_hbox_new(FALSE, 10);
 	gtk_box_pack_start(GTK_BOX(section_content_box), hbox, FALSE, FALSE, 10);
 	gtk_widget_show(hbox);
-	boot_asui_button = new_toggle_button(hbox, ASUI_NAME, click_boot_asui_button_callback, (asui_boot ? TRUE : FALSE), TRUE,TRUE);
-	boot_systemui_button = new_toggle_button(hbox, SYSTEMUI_NAME, click_boot_systemui_button_callback, (systemui_boot ? TRUE : FALSE), TRUE,TRUE);
+	boot_asui_button = new_toggle_button(hbox, ASUI_NAME, click_boot_asui_button_callback, NULL, (asui_boot ? TRUE : FALSE), TRUE,TRUE);
+	boot_systemui_button = new_toggle_button(hbox, SYSTEMUI_NAME, click_boot_systemui_button_callback, NULL, (systemui_boot ? TRUE : FALSE), TRUE,TRUE);
 
 	new_separator();
 
@@ -593,7 +608,8 @@ service->allow_boot = 0;
 	gtk_widget_show(hbox);
 
 	network_enabled = !file_exists("/etc/rc5.d/K20wlancond") && !file_exists("/etc/rc5.d/K15icd2") && !file_exists("/etc/rc5.d/K20osso-ipv6");
-	new_toggle_button(hbox, (network_enabled ? "RC5 networking is ENABLED" : "RC5 networking is DISABLED"), toggle_network_callback, network_enabled, TRUE,FALSE);
+	new_toggle_button(hbox, (network_enabled ? "RC5 networking is ENABLED" : "RC5 networking is DISABLED"),
+						toggle_network_callback, NULL, network_enabled, TRUE,FALSE);
 
 	new_separator();
 
@@ -622,7 +638,8 @@ service->allow_boot = 0;
 		// start, stop, state buttons
 		if(service->proc_name && service->allow_startstop){
 			// show start or stop button, depending on state
-			service->widget_start = new_button_right(hbox, (service->running == IS_STARTED ? "Stop" : "Start"), click_startstop_service_callback, (void *)service);
+			service->widget_start = new_toggle_button_right(hbox, (service->running == IS_STARTED ? "Stop" : "Start"), click_startstop_service_callback,
+															(void *)service, (service->running == IS_STARTED ? TRUE : FALSE));
 		} else if(service->allow_startstop){
 			// can't tell if service is running, show start and stop buttons and let user decide
 			if(service->allow_restart)
