@@ -95,7 +95,7 @@ static void draw_mem_format( char *name, unsigned free, unsigned total, unsigned
 
 //////////////////////////////////////////////////////////////////////////
 
-static unsigned show_swap = 0;
+static unsigned show_swap = 0, charge_animation_cycle = 1;
 
 static int battery_widget_x, battery_widget_y;
 
@@ -135,6 +135,8 @@ void draw_battery_widget( unsigned force, int x, int y ){
 		}
 		if(hw_device_locked){ title_size = 22; pct_size -= 4; y_base = y+20; } else { title_size = 26; y_base = y+16; }
 
+		if(hw_battery.status == BATTERY_CHARGING) animate_battery_widget(0);
+
 		// status and percentage
 		w = draw_text(title, title_size, title_color, x+12, y_base, ALIGN_LEFT, ALIGN_TOP, 0);
 		if(hw_battery.capacity < 100.0)
@@ -269,6 +271,33 @@ void draw_battery_widget( unsigned force, int x, int y ){
 	}
 }
 
+void animate_battery_widget( unsigned increment ){
+	int x = battery_widget_x, y = battery_widget_y, h;
+	if(increment) x_set_color(bg_color);
+	if(hw_device_locked){
+		if(increment) x_fill_rectangle(x+3, y+19, 6, 20);
+		y += 19 + (4-charge_animation_cycle)*20/4;
+		h = charge_animation_cycle * 20/4;
+	} else {
+		if(increment) x_fill_rectangle(x+3, y+15, 6, 24);
+		y += 15 + (4-charge_animation_cycle)*24/4;
+		h = charge_animation_cycle * 24/4;
+	}
+
+	x_set_color(green_color);
+	x_fill_rectangle(x+3, y, 6, h);
+
+	if(increment){
+		charge_animation_cycle++;
+		if(charge_animation_cycle > 4) charge_animation_cycle = 1;
+
+		// reset charge animation timer
+		reset_timer(&charge_animation_timer);
+
+		x_flush();
+	}
+}
+
 //////////////////////////////////////////////////////////////////////////
 
 static s_tap_throttler battery_throttle;
