@@ -3,3 +3,6 @@
 
 // for minimal UI, popup window and battery refresh timer
 void draw_battery_widget( unsigned force, int x, int y );
+
+// for charge animation timer
+void animate_battery_widget( unsigned increment );
