@@ -32,6 +32,7 @@
 #include "hardware.h"
 #include "dialog.h"
 #include "dbus.h"
+#include "dsme.h"
 #include "alarm.h"
 
 #include "images/reboot.xpm"
@@ -48,6 +49,8 @@
 #include "widget_battery.h"
 // draw function for popup window
 #include "widget_clock.h"
+// key event function for audio lock
+#include "button_audio_lock.h"
 
 ////////////////////////////////////////////////////////////////////////// GLOBALS
 
@@ -374,6 +377,35 @@ void window_reload( unsigned init ){
 	generate_rotation_icons(init);
 }
 
+void window_disable_keybutton_events( ){
+	if(!window.tk_events_disabled){
+		XSelectInput(window.display, window.window, StructureNotifyMask
+			| (use_minimal_ui ? 0 : FocusChangeMask) | ExposureMask);
+		window.tk_events_disabled = current_time;
+
+		// remove key and screen events from queue
+		XEvent e;
+		while(XCheckMaskEvent(window.display, ButtonPress|MotionNotify|ButtonRelease|KeyPress|KeyRelease, &e)){
+			debug_write("removed TK event from queue");
+		}
+	}
+}
+void window_enable_all_events( ){
+	if(window.tk_events_disabled){
+		// remove key and screen events from queue
+		XEvent e;
+		while(XCheckMaskEvent(window.display, ButtonPress|MotionNotify|ButtonRelease|KeyPress|KeyRelease, &e)){
+			debug_write("removed TK event from queue");
+		}
+
+		XSelectInput(window.display, window.window, StructureNotifyMask
+			| ButtonPressMask | ButtonMotionMask | ButtonReleaseMask
+			| KeyPressMask | KeyReleaseMask
+			| (use_minimal_ui ? 0 : FocusChangeMask) | ExposureMask);
+		window.tk_events_disabled = 0.0;
+	}
+}
+
 static int window_create( unsigned first_time ){
 	if(first_time){
 		// open display
@@ -423,10 +455,8 @@ static int window_create( unsigned first_time ){
 										0, CopyFromParent, CopyFromParent, CopyFromParent, 0, &winattr);
 		window.gc = XCreateGC(window.display, window.window, 0, NULL);
 		XSetGraphicsExposures(window.display, window.gc, False);
-		XSelectInput(window.display, window.window, StructureNotifyMask
-			| ButtonPressMask | ButtonMotionMask | ButtonReleaseMask
-			| KeyPressMask | KeyReleaseMask
-			| (use_minimal_ui ? 0 : FocusChangeMask) | ExposureMask);
+		window.tk_events_disabled = current_time; // force window_enable_all_events()
+		window_enable_all_events();
 		if(window.supports_rotation)
 			XRRSelectInput(window.display, window.window, RRScreenChangeNotifyMask);
 
@@ -564,6 +594,7 @@ void window_map( unsigned slide ){
 	window_close_blank();
 	window_close_popup();
 
+	// position window offscreen in preparation for the slide on to screen
 	if(slide && cfg_window_slide_map){
 		if(window.width > window.height)
 			window_slide(0, window.height);
@@ -606,15 +637,16 @@ void window_map( unsigned slide ){
 
 	hw_refresh_cpu();
 	svc_refresh();
-	brightness_widget_page = volume_widget_page = battery_widget_page = wifi_widget_page = bluetooth_widget_page = usb_widget_page = flightmode_button_page = keyrepeat_button_page = screenstayslit_button_page = screenautolock_button_page = primary_widgets;
+	brightness_widget_page = volume_widget_page = battery_widget_page = wifi_widget_page = bluetooth_widget_page = usb_widget_page = flightmode_button_page = audiolock_button_page = keyrepeat_button_page = screenstayslit_button_page = screenautolock_button_page = primary_widgets;
 	hw_refresh(); // query all values and then reset pages to prevent further queryies unless on current page
-	brightness_widget_page = volume_widget_page = battery_widget_page = wifi_widget_page = bluetooth_widget_page = usb_widget_page = flightmode_button_page = keyrepeat_button_page = screenstayslit_button_page = screenautolock_button_page = !primary_widgets;
+	brightness_widget_page = volume_widget_page = battery_widget_page = wifi_widget_page = bluetooth_widget_page = usb_widget_page = flightmode_button_page = audiolock_button_page = keyrepeat_button_page = screenstayslit_button_page = screenautolock_button_page = !primary_widgets;
 
 	window.is_mapped = 1;
 
 	draw_window(1); // force
 
 	if(slide && cfg_window_slide_map){
+		window_disable_keybutton_events();
 		if(window.width > window.height){
 			while(window.y > 0){
 				window_slide(0, window.y-SLIDE_STEP);
@@ -628,11 +660,13 @@ void window_map( unsigned slide ){
 				usleep(SLIDE_INTERVAL);
 			}
 		}
+		window_enable_all_events();
 	}
 
 	// open popup window if it has been more than 10 seconds since it was last closed
 	if(current_dialog_draw != draw_alarm && cfg_popup_onmap && current_time - popup_window_close_time > 10.0)
 		window_open_popup();
+	debug_write("window_map() window is now visible");
 }
 
 void window_unmap( unsigned slide ){
@@ -641,6 +675,7 @@ void window_unmap( unsigned slide ){
 	window_close_popup();
 
 	if(slide && cfg_window_slide_unmap){
+		window_disable_keybutton_events();
 		if(window.width > window.height){
 			while(window.y < (int)window.height-SLIDE_STEP){
 				window_slide(0, window.y+SLIDE_STEP);
@@ -654,6 +689,7 @@ void window_unmap( unsigned slide ){
 				usleep(SLIDE_INTERVAL);
 			}
 		}
+		window_enable_all_events();
 	}
 
 	// close dialog if open -- this is needed to reset anything it did to the main loop (the process viewer refresh)
@@ -677,6 +713,7 @@ void window_unmap( unsigned slide ){
 	if(window.x || window.y) window_slide(0,0);
 
 	window.is_mapped = 0;
+	debug_write("window_unmap() window is now hidden");
 }
 
 void window_slide( int x, int y ){
@@ -722,7 +759,7 @@ void rotate_screen( e_orientation new_orientation, unsigned keep_mapped ){
 	int xrr_size, needs_resize = 0;
 	Window tmp_window = 0;
 
-	if(new_orientation == window.orientation) return;
+	if(!window.supports_rotation || new_orientation == window.orientation) return;
 
 	// rotate the dpad
 	rotate_dpad(new_orientation);
@@ -898,6 +935,8 @@ void update_orientation( XEvent *event ){
 	XRRScreenChangeNotifyEvent *xrr_event = (XRRScreenChangeNotifyEvent *)event;
 	unsigned flip = 0;
 
+	if(!window.supports_rotation) return;
+
 // TODO: an X event is only sent when the screen dimensions change and not when the screen orientation is merely flipped
 
 	// did it flip or resize
@@ -983,7 +1022,7 @@ int check_orientation( ){
 	Rotation current_xrr_orientation;
 
 	// only check once every 10 seconds
-	if(last_orientation_check + 10 > current_time) return 0;
+	if(!window.supports_rotation || last_orientation_check + 10 > current_time) return 0;
 	last_orientation_check = current_time;
 
 	XRRScreenConfiguration *xrr_config = XRRGetScreenInfo(window.display, window.root_window);
@@ -1105,7 +1144,7 @@ void window_open_blank( ){
 }
 
 void window_close_blank( ){
-	if(blank_window_open){
+	if(blank_window_open && !hw_audio_lock){
 		debug_write("window_close_blank()");
 
 		blank_fd = 0;
@@ -1150,23 +1189,34 @@ unsigned window_blank_events( ){
 			// ignore taps from the blank window
 			break;
 		case ButtonRelease:
+			if(hw_audio_lock) break;
 			// close the blank window
 			window_close_blank();
 			if(cfg_tkactive_notifications) notify_screen_unlocked();
 			return 0; // get out of this loop or it will segfault
 		case KeyPress:
 			// ignore keys from the blank window
+			if(hw_audio_lock){
+				// this event will turn on the screen, if off
+				dsme_display_state_waiting = 0; // reset blanking pause check
+				// screen was also unlock, although MCE still thinks it is locked
+				hw_lock_screen();
+			}
 			break;
 		case KeyRelease:
 			debug_write("KeyRelease[blank]: %d", e.xkey.keycode);
 			if(cfg_power_unlock_key && hw_screen.locked){
 				debug_write("-- secondary key required to unlock = %d", power_unlock_keys[cfg_power_unlock_key]);
-				if(check_secondary_key(e.xkey.keycode)){
+				if(check_secondary_key(e.xkey.keycode) && waiting_for_power_unlock_key){
 					window_close_blank();
 					mce_unlock_screen();
 					return 0; // get out of this loop or it will segfault
-				} else
+				} else if(hw_audio_lock)
+					audio_lock_events(&e);
+				else
 					notify_power_unlock_key();
+			} else if(hw_audio_lock){
+				audio_lock_events(&e);
 			} else {
 				// close the blank window
 				window_close_blank();
