@@ -19,6 +19,7 @@ typedef struct s_window {
 	unsigned supports_rotation, xrr_event_base;
 	e_orientation orientation;
 	unsigned has_focus;
+	double tk_events_disabled;
 } s_window;
 
 extern s_window window;
@@ -46,6 +47,9 @@ extern double popup_window_open_time;
 
 void window_reload( unsigned init );
 
+void window_disable_keybutton_events( );
+void window_enable_all_events( );
+
 int window_init( );
 
 void window_set_theme( unsigned white_theme );
